==> pystan-2.11.0.0.zip: pystan-2.11.0.0/pystan/stan/lib/stan_math_2.11.0/doc/api/html/search/functions_4.js <==
var searchData=
[
  ['e',['e',['../namespacestan_1_1math.html#a3b650a0131d41167ef4837ecc7d02be5',1,'stan::math']]],
  ['eigenvalues_5fsym',['eigenvalues_sym',['../namespacestan_1_1math.html#a2e454ec91241f2f6e70aa05e7b7698ff',1,'stan::math']]],
  ['eigenvectors_5fsym',['eigenvectors_sym',['../namespacestan_1_1math.html#a9fd77067fef0a78dd5d8f9527969631e',1,'stan::math']]],
  ['elt_5fdivide',['elt_divide',['../namespacestan_1_1math.html#a75c3cc187f569c795118c72bcc1e5c58',1,'stan::math::elt_divide(const Eigen::Matrix&lt; T1, R, C &gt; &amp;m1, const Eigen::Matrix&lt; T2, R, C &gt; &amp;m2)'],['../namespacestan_1_1math.html#adc5d04e1b1dde0ea7455380ec27d4528',1,'stan::math::elt_divide(const Eigen::Matrix&lt; T1, R, C &gt; &amp;m, T2 s)'],['../namespacestan_1_1math.html#ad4d728ca306346624b833cee2777c23d',1,'stan::math::elt_divide(T1 s, const Eigen::Matrix&lt; T2, R, C &gt; &amp;m)']]],
  ['elt_5fmultiply',['elt_multiply',['../namespacestan_1_1math.html#a2edc3d65b32928692984bd66a1b3bb56',1,'stan::math']]],
  ['empty_5fnested',['empty_nested',['../namespacestan_1_1math.html#a430f171295b91277dc60dfa2177c7c0b',1,'stan::math']]],
  ['epsilon',['epsilon',['../structstd_1_1numeric__limits_3_01stan_1_1math_1_1fvar_3_01_t_01_4_01_4.html#abf9a7000542d5141f8f6791282aecc5e',1,'std::numeric_limits&lt; stan::math::fvar&lt; T &gt; &gt;::epsilon()'],['../struct_eigen_1_1_num_traits_3_01stan_1_1math_1_1fvar_3_01_t_01_4_01_4.html#a8532a2c2276f85829398e8eed1fffede',1,'Eigen::NumTraits&lt; stan::math::fvar&lt; T &gt; &gt;::epsilon()'],['../structstd_1_1numeric__limits_3_01stan_1_1math_1_1var_01_4.html#a9721f6791342af12c178669b3ed87ccc',1,'std::numeric_limits&lt; stan::math::var &gt;::epsilon()'],['../struct_eigen_1_1_num_traits_3_01stan_1_1math_1_1var_01_4.html#a6ee32c875e248190487e374103f1d599',1,'Eigen::NumTraits&lt; stan::math::var &gt;::epsilon()']]],
  ['erf',['erf',['../namespacestan_1_1math.html#aa283efca22c0544054a6534443e6e762',1,'stan::math::erf(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#ad66027047e2bc65d71a1c2617a36d4cb',1,'stan::math::erf(const T &amp;x)'],['../namespacestan_1_1math.html#a759d52872682fdf0d6a7a6d75b4f1d9e',1,'stan::math::erf(const var &amp;a)']]],
  ['erfc',['erfc',['../namespacestan_1_1math.html#ab4c763e4f09069eed96a4e96e33ea8ea',1,'stan::math::erfc(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#adae1cb50db676daa267f9865c2d2c83a',1,'stan::math::erfc(const T &amp;x)'],['../namespacestan_1_1math.html#a8a8543e9c729e794bcbdff2ed223eb45',1,'stan::math::erfc(const var &amp;a)']]],
  ['eval_5fgevv',['eval_gevv',['../classstan_1_1math_1_1gevv__vvv__vari.html#a9baad1e3c1fe91eabc1cdb68982426df',1,'stan::math::gevv_vvv_vari']]],
  ['exp',['exp',['../namespacestan_1_1math.html#a11f31444e8584e4debf0d6b706d66880',1,'stan::math::exp(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#aef19104a8e5d43b9e60c90bd15edaea0',1,'stan::math::exp(const T &amp;x)'],['../namespacestan_1_1math.html#ae43b048d4a5f53f94501773c93689a65',1,'stan::math::exp(const var &amp;a)']]],
  ['exp2',['exp2',['../namespacestan_1_1math.html#a8c3a577694c8f584e56160580fe0821b',1,'stan::math::exp2(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#a0ef734d7c3b8ebd689012295bf826e94',1,'stan::math::exp2(const T y)'],['../namespacestan_1_1math.html#a9fd4650bbf246a10ac798c71da8b99d5',1,'stan::math::exp2(const var &amp;a)']]],
  ['exp_5fmod_5fnormal_5fccdf_5flog',['exp_mod_normal_ccdf_log',['../namespacestan_1_1math.html#a497ff815eeadaffe3204d33359c4be82',1,'stan::math']]],
  ['exp_5fmod_5fnormal_5fcdf',['exp_mod_normal_cdf',['../namespacestan_1_1math.html#a2b29301645f48dedc57b97409062250c',1,'stan::math']]],
  ['exp_5fmod_5fnormal_5fcdf_5flog',['exp_mod_normal_cdf_log',['../namespacestan_1_1math.html#ad0e32ac964461952d77df48cd30c6f1d',1,'stan::math']]],
  ['exp_5fmod_5fnormal_5flog',['exp_mod_normal_log',['../namespacestan_1_1math.html#af27bb81f9220a9ba9082903fd55dff66',1,'stan::math::exp_mod_normal_log(const T_y &amp;y, const T_loc &amp;mu, const T_scale &amp;sigma, const T_inv_scale &amp;lambda)'],['../namespacestan_1_1math.html#a50a3cd94db2760437551ea466247cf8e',1,'stan::math::exp_mod_normal_log(const T_y &amp;y, const T_loc &amp;mu, const T_scale &amp;sigma, const T_inv_scale &amp;lambda)']]],
  ['exp_5fmod_5fnormal_5frng',['exp_mod_normal_rng',['../namespacestan_1_1math.html#a40d3c6fbf610e2c0e997a039f2ed98e8',1,'stan::math']]],
  ['expm1',['expm1',['../namespacestan_1_1math.html#a8a76b658b94fcf8943f4fb41c586ec94',1,'stan::math::expm1(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#a82d349345d9009f790094fdaa6918283',1,'stan::math::expm1(const T &amp;x)'],['../namespacestan_1_1math.html#a8c632ff37556a4989fb351042da3a05a',1,'stan::math::expm1(const stan::math::var &amp;a)']]],
  ['exponential_5fccdf_5flog',['exponential_ccdf_log',['../namespacestan_1_1math.html#a42c92f31b24600c6ce05b4f21f54fb00',1,'stan::math']]],
  ['exponential_5fcdf',['exponential_cdf',['../namespacestan_1_1math.html#ac753dcf58b69f0bbf7b001bfe19a3e44',1,'stan::math']]],
  ['exponential_5fcdf_5flog',['exponential_cdf_log',['../namespacestan_1_1math.html#a8fbf986074ea063853c8d244c3c17e0f',1,'stan::math']]],
  ['exponential_5flog',['exponential_log',['../namespacestan_1_1math.html#addcdf998d9f336fd9e4118acc6c7a129',1,'stan::math::exponential_log(const T_y &amp;y, const T_inv_scale &amp;beta)'],['../namespacestan_1_1math.html#af3653c4e36237f4d7403af9f64abbcd2',1,'stan::math::exponential_log(const T_y &amp;y, const T_inv_scale &amp;beta)']]],
  ['exponential_5frng',['exponential_rng',['../namespacestan_1_1math.html#a6cfcce609912c9a6e1b2fad1e5055a1d',1,'stan::math']]]
];

==> pystan-2.12.0.0.zip: pystan-2.12.0.0/pystan/stan/lib/stan_math_2.12.0/doc/api/html/search/functions_4.js <==
var searchData=
[
  ['e',['e',['../namespacestan_1_1math.html#a3b650a0131d41167ef4837ecc7d02be5',1,'stan::math']]],
  ['eigenvalues_5fsym',['eigenvalues_sym',['../namespacestan_1_1math.html#a2e454ec91241f2f6e70aa05e7b7698ff',1,'stan::math']]],
  ['eigenvectors_5fsym',['eigenvectors_sym',['../namespacestan_1_1math.html#a9fd77067fef0a78dd5d8f9527969631e',1,'stan::math']]],
  ['elt_5fdivide',['elt_divide',['../namespacestan_1_1math.html#a75c3cc187f569c795118c72bcc1e5c58',1,'stan::math::elt_divide(const Eigen::Matrix&lt; T1, R, C &gt; &amp;m1, const Eigen::Matrix&lt; T2, R, C &gt; &amp;m2)'],['../namespacestan_1_1math.html#adc5d04e1b1dde0ea7455380ec27d4528',1,'stan::math::elt_divide(const Eigen::Matrix&lt; T1, R, C &gt; &amp;m, T2 s)'],['../namespacestan_1_1math.html#ad4d728ca306346624b833cee2777c23d',1,'stan::math::elt_divide(T1 s, const Eigen::Matrix&lt; T2, R, C &gt; &amp;m)']]],
  ['elt_5fmultiply',['elt_multiply',['../namespacestan_1_1math.html#a2edc3d65b32928692984bd66a1b3bb56',1,'stan::math']]],
  ['empty_5fnested',['empty_nested',['../namespacestan_1_1math.html#a430f171295b91277dc60dfa2177c7c0b',1,'stan::math']]],
  ['epsilon',['epsilon',['../structstd_1_1numeric__limits_3_01stan_1_1math_1_1fvar_3_01_t_01_4_01_4.html#abf9a7000542d5141f8f6791282aecc5e',1,'std::numeric_limits&lt; stan::math::fvar&lt; T &gt; &gt;::epsilon()'],['../structstd_1_1numeric__limits_3_01stan_1_1math_1_1var_01_4.html#a9721f6791342af12c178669b3ed87ccc',1,'std::numeric_limits&lt; stan::math::var &gt;::epsilon()']]],
  ['erf',['erf',['../namespacestan_1_1math.html#aa283efca22c0544054a6534443e6e762',1,'stan::math::erf(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#ad66027047e2bc65d71a1c2617a36d4cb',1,'stan::math::erf(const T &amp;x)'],['../namespacestan_1_1math.html#a759d52872682fdf0d6a7a6d75b4f1d9e',1,'stan::math::erf(const var &amp;a)']]],
  ['erfc',['erfc',['../namespacestan_1_1math.html#ab4c763e4f09069eed96a4e96e33ea8ea',1,'stan::math::erfc(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#adae1cb50db676daa267f9865c2d2c83a',1,'stan::math::erfc(const T &amp;x)'],['../namespacestan_1_1math.html#a8a8543e9c729e794bcbdff2ed223eb45',1,'stan::math::erfc(const var &amp;a)']]],
  ['eval_5fgevv',['eval_gevv',['../classstan_1_1math_1_1gevv__vvv__vari.html#ab65e5affbfbfcaf260d76d1f06c87939',1,'stan::math::gevv_vvv_vari']]],
  ['exp',['exp',['../namespacestan_1_1math.html#a11f31444e8584e4debf0d6b706d66880',1,'stan::math::exp(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#aef19104a8e5d43b9e60c90bd15edaea0',1,'stan::math::exp(const T &amp;x)'],['../namespacestan_1_1math.html#acb5fe78687ec6feb16e5031598917cc2',1,'stan::math::exp(int x)'],['../namespacestan_1_1math.html#ae43b048d4a5f53f94501773c93689a65',1,'stan::math::exp(const var &amp;a)']]],
  ['exp2',['exp2',['../namespacestan_1_1math.html#a8c3a577694c8f584e56160580fe0821b',1,'stan::math::exp2(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#a0ef734d7c3b8ebd689012295bf826e94',1,'stan::math::exp2(const T y)'],['../namespacestan_1_1math.html#a9fd4650bbf246a10ac798c71da8b99d5',1,'stan::math::exp2(const var &amp;a)']]],
  ['exp_5fmod_5fnormal_5fccdf_5flog',['exp_mod_normal_ccdf_log',['../namespacestan_1_1math.html#a497ff815eeadaffe3204d33359c4be82',1,'stan::math']]],
  ['exp_5fmod_5fnormal_5fcdf',['exp_mod_normal_cdf',['../namespacestan_1_1math.html#a2b29301645f48dedc57b97409062250c',1,'stan::math']]],
  ['exp_5fmod_5fnormal_5fcdf_5flog',['exp_mod_normal_cdf_log',['../namespacestan_1_1math.html#ad0e32ac964461952d77df48cd30c6f1d',1,'stan::math']]],
  ['exp_5fmod_5fnormal_5flog',['exp_mod_normal_log',['../namespacestan_1_1math.html#af27bb81f9220a9ba9082903fd55dff66',1,'stan::math::exp_mod_normal_log(const T_y &amp;y, const T_loc &amp;mu, const T_scale &amp;sigma, const T_inv_scale &amp;lambda)'],['../namespacestan_1_1math.html#a50a3cd94db2760437551ea466247cf8e',1,'stan::math::exp_mod_normal_log(const T_y &amp;y, const T_loc &amp;mu, const T_scale &amp;sigma, const T_inv_scale &amp;lambda)']]],
  ['exp_5fmod_5fnormal_5frng',['exp_mod_normal_rng',['../namespacestan_1_1math.html#a40d3c6fbf610e2c0e997a039f2ed98e8',1,'stan::math']]],
  ['expm1',['expm1',['../namespacestan_1_1math.html#a8a76b658b94fcf8943f4fb41c586ec94',1,'stan::math::expm1(const fvar&lt; T &gt; &amp;x)'],['../namespacestan_1_1math.html#a82d349345d9009f790094fdaa6918283',1,'stan::math::expm1(const T &amp;x)'],['../namespacestan_1_1math.html#a974d9d6b021e75ee0ba7146d221beed2',1,'stan::math::expm1(const var &amp;a)']]],
  ['exponential_5fccdf_5flog',['exponential_ccdf_log',['../namespacestan_1_1math.html#a42c92f31b24600c6ce05b4f21f54fb00',1,'stan::math']]],
  ['exponential_5fcdf',['exponential_cdf',['../namespacestan_1_1math.html#ac753dcf58b69f0bbf7b001bfe19a3e44',1,'stan::math']]],
  ['exponential_5fcdf_5flog',['exponential_cdf_log',['../namespacestan_1_1math.html#a8fbf986074ea063853c8d244c3c17e0f',1,'stan::math']]],
  ['exponential_5flog',['exponential_log',['../namespacestan_1_1math.html#addcdf998d9f336fd9e4118acc6c7a129',1,'stan::math::exponential_log(const T_y &amp;y, const T_inv_scale &amp;beta)'],['../namespacestan_1_1math.html#af3653c4e36237f4d7403af9f64abbcd2',1,'stan::math::exponential_log(const T_y &amp;y, const T_inv_scale &amp;beta)']]],
  ['exponential_5frng',['exponential_rng',['../namespacestan_1_1math.html#a6cfcce609912c9a6e1b2fad1e5055a1d',1,'stan::math']]]
];
